BuiltinPathElem

Enum BuiltinPathElem 

pub enum BuiltinPathElem {
    Tuple(usize),
    Str,
    Closure,
    Use,
    AnonConst,
    PromotedConst,
    ClosureAsFn,
    DropGlue,
    VTable,
    VTableMethod,
    VTableDropShim,
}
Used for builtin items, rather than hardcoding these as strings.

Variants



Tuple(usize)

The tuple of the given arity.



Str

str, which is a struct containing a [u8] the standard library expects to be valid UTF-8.



Closure

A closure.



Use

A use declaration.



AnonConst

An anonymous constant.



PromotedConst

A constant that rustc promoted out of a body.



ClosureAsFn

The function item we generate for a closure that is cast to a function pointer.



DropGlue

The method we add to the Destruct trait to hold the drop glue.



VTable

The vtable struct of a trait, or the vtable global of a trait impl.



VTableMethod

The version of a method that is stored in a vtable.



VTableDropShim

The drop_in_place shim stored in a vtable.

Implementations

Source

impl BuiltinPathElem

pub fn is_tuple(&self) -> bool

pub fn is_str(&self) -> bool

pub fn is_closure(&self) -> bool

pub fn is_use(&self) -> bool

pub fn is_anon_const(&self) -> bool

pub fn is_promoted_const(&self) -> bool

pub fn is_closure_as_fn(&self) -> bool

pub fn is_drop_glue(&self) -> bool

pub fn is_vtable(&self) -> bool

pub fn is_vtable_method(&self) -> bool

pub fn is_vtable_drop_shim(&self) -> bool

Source

impl BuiltinPathElem

pub fn as_tuple(&self) -> Option<&usize>

pub fn as_str(&self) -> Option<()>

pub fn as_closure(&self) -> Option<()>

pub fn as_use(&self) -> Option<()>

pub fn as_anon_const(&self) -> Option<()>

pub fn as_promoted_const(&self) -> Option<()>

pub fn as_closure_as_fn(&self) -> Option<()>

pub fn as_drop_glue(&self) -> Option<()>

pub fn as_vtable(&self) -> Option<()>

pub fn as_vtable_method(&self) -> Option<()>

pub fn as_vtable_drop_shim(&self) -> Option<()>

Source

impl BuiltinPathElem

pub fn as_tuple_mut(&mut self) -> Option<&mut usize>

pub fn as_str_mut(&mut self) -> Option<()>

pub fn as_closure_mut(&mut self) -> Option<()>

pub fn as_use_mut(&mut self) -> Option<()>

pub fn as_anon_const_mut(&mut self) -> Option<()>

pub fn as_promoted_const_mut(&mut self) -> Option<()>

pub fn as_closure_as_fn_mut(&mut self) -> Option<()>

pub fn as_drop_glue_mut(&mut self) -> Option<()>

pub fn as_vtable_mut(&mut self) -> Option<()>

pub fn as_vtable_method_mut(&mut self) -> Option<()>

pub fn as_vtable_drop_shim_mut(&mut self) -> Option<()>

Source

impl BuiltinPathElem

pub fn is_rust_name(self) -> bool

If this builtin name is also how Rust refers to the item, in which case we don’t need to put braces around the name, as it is part of the actual path of the item.

pub fn ident(self) -> &'static str

The identifier we use to refer to this element.